package tests

import (
	"encoding/base64"
	"io/ioutil"
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
)

func TestVarlist(t *testing.T) {
	tester := NewAPITester(t)
	defer tester.Close()

	defer tester.Logout()
	tester.Login("admin", "admin")

	tester.CreateUser("janedoe", "janedoe")
	tester.Login("janedoe", "janedoe")

	tester.Run("od+mustache", func(t *testing.T) {
		b, err := ioutil.ReadFile("../dependencies/od-templating/examples/basics.odt")
		require.NoError(t, err)
		var result []string
		tester.MustPostJSON(
			"/api/v1/varlist",
			JSONObj{
				"language":    "od+mustache",
				"produces":    "application/vnd.oasis.opendocument.text",
				"body-format": "base64",
				"body":        base64.StdEncoding.EncodeToString(b),
			},
			&result,
		)

		assert.Equal(t, []string{
			"person.firstname",
			"person.lastname",
			"person.skill",
			"person.birthday",
			"person.time",
			"person.datetime",
			"person.image.body",
			"person.image.mime-type",
		}, result)
	})

	tester.Run("mustache", func(t *testing.T) {
		var result []string
		tester.MustPostJSON(
			"/api/v1/varlist",
			JSONObj{
				"language":    "mustache",
				"produces":    "text/mjml",
				"body-format": "text",
				"body":        "<mjml> <mj-body> <mj-section> <mj-column> <mj-text>hello {{name}}</mj-text> </mj-column> </mj-section> </mj-body> </mjml>",
			},
			&result,
		)

		assert.Equal(t, []string{
			"name",
		}, result)
	})
}
